<?php
//
// This module reads and prints exif details from current image
// if image details bar is not displayed (by Show Details button).
//
// Feel free to add, remove and rearrange parameters.
//
if ($image->IsImage() && // This will protect against direct include
    !($bShowDetails && $g_bShowEXIFDetailsButton))
{
    // Read EXIF
    if ($g_bForceDAlbumEXIFCode || !extension_loaded('exif'))
    {
        require_once(DALBUM_ROOT . "/include/exif.php");
        $exif=@exif_php_read_data(absfname($image->m_sFullFilename));
    }
    else
    {
        $exif=@exif_read_data(absfname($image->m_sFullFilename));
    }

    if ($exif===false)
        $exif=array();

    $data=array();

    // Resolution
    if ($image->m_nX>0 && $image->m_nY>0)
        $data[]="|({$image->m_nX}x{$image->m_nY})";

    // Date/time
    if (isset($exif['DateTime']))
    {
        $date=$exif['DateTime'];
        $date=split(':',str_replace(' ',':',$date));
        $date="{$date[0]}-{$date[1]}-{$date[2]} {$date[3]}:{$date[4]}:{$date[5]}";
        $date=strftime($lang['cExiflineDateFormat'],strtotime($date));
        $data[]="|$date";
    }

    // ISO speed
    if (isset($exif['ISOSpeedRatings']))
        $data[]=$lang['cExiflineISOSpeedRatings']."|".$exif['ISOSpeedRatings'];

    // Exposure
    if (isset($exif['ExposureTime']))
    {
        list($d1,$d2)=split('/',$exif['ExposureTime']);
        if ($d1>0 && $d2>0)
            $e=$d1/$d2;
        else
            $e=$exif['ExposureTime'];
        if ($e<1 && $e>0)
            $e="1/" . round(1/$e,0) . " s";
        else
            $e=round($e,1) ." s";

        $data[]=$lang['cExiflineExposure']."|".$e;
    }

    // Aperture
    if (isset($exif['COMPUTED']['ApertureFNumber']))
        $data[]="{$lang['cExiflineAperture']}|{$exif['COMPUTED']['ApertureFNumber']}";

    // Flash
    if (isset($exif['Flash']))
    {
        $e=$lang[($exif['Flash']&1)?'showExifFlashYes':'showExifFlashNo'];
        $data[]="{$lang['cExiflineFlash']}:|$e";
    }

    // Combine all together into one line
    $sExifDetails="";
    if (!empty($data))
    {
        foreach ($data as $d)
        {
            $arr=split('\|',$d);
            if (count($arr)==2)
            {
                if (!empty($sExifDetails))
                    $sExifDetails.="; ";
                $sExifDetails.="{$arr[0]}{$arr[1]}";
            }
        }
    }
    // print the line
    print $sExifDetails;
}
?>